==> haskell-stmonadtrans-0.4.5-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-stmonadtrans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 STMonadTrans
version:              0.4.5
visibility:           public
id:                   STMonadTrans-0.4.5-FVf2kcxMchyA53wOwRats8
key:                  STMonadTrans-0.4.5-FVf2kcxMchyA53wOwRats8
license:              BSD-3-Clause
maintainer:           josef.svenningsson@gmail.com
author:               Josef Svenningsson
synopsis:             A monad transformer version of the ST monad
description:
    A monad transformer version of the ST monad
    Warning! This monad transformer should not be used with monads that
    can contain multiple answers, like the list monad. The reason is that
    the state token will be duplicated across the different answers and
    this causes Bad Things to happen (such as loss of referential
    transparency). Safe monads include the monads State, Reader, Writer,
    Maybe and combinations of their corresponding monad transformers.

category:             Monads
abi:                  1d07a3b469dccfcf6e60f0e40a91ab53
exposed:              True
exposed-modules:
    Control.Monad.ST.Trans Control.Monad.ST.Trans.Internal

import-dirs:          /usr/lib/ghc-8.10.3/site-local/STMonadTrans-0.4.5
library-dirs:         /usr/lib/ghc-8.10.3/site-local/STMonadTrans-0.4.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/STMonadTrans-0.4.5
hs-libraries:         HSSTMonadTrans-0.4.5-FVf2kcxMchyA53wOwRats8
depends:              array-0.5.4.0 base-4.14.1.0 mtl-2.2.2
haddock-interfaces:
    /usr/share/doc/haskell-stmonadtrans/html/STMonadTrans.haddock

haddock-html:         /usr/share/doc/haskell-stmonadtrans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stmonadtrans-0.4.5-29-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-stmonadtrans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 STMonadTrans
version:              0.4.5
visibility:           public
id:                   STMonadTrans-0.4.5-DxK3dzCRBfUJix6LovWkkZ
key:                  STMonadTrans-0.4.5-DxK3dzCRBfUJix6LovWkkZ
license:              BSD-3-Clause
maintainer:           josef.svenningsson@gmail.com
author:               Josef Svenningsson
synopsis:             A monad transformer version of the ST monad
description:
    A monad transformer version of the ST monad
    Warning! This monad transformer should not be used with monads that
    can contain multiple answers, like the list monad. The reason is that
    the state token will be duplicated across the different answers and
    this causes Bad Things to happen (such as loss of referential
    transparency). Safe monads include the monads State, Reader, Writer,
    Maybe and combinations of their corresponding monad transformers.

category:             Monads
abi:                  687e01458695a4e5f26a87965113713e
exposed:              True
exposed-modules:
    Control.Monad.ST.Trans Control.Monad.ST.Trans.Internal

import-dirs:          /usr/lib/ghc-8.10.4/site-local/STMonadTrans-0.4.5
library-dirs:         /usr/lib/ghc-8.10.4/site-local/STMonadTrans-0.4.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/STMonadTrans-0.4.5
hs-libraries:         HSSTMonadTrans-0.4.5-DxK3dzCRBfUJix6LovWkkZ
depends:              array-0.5.4.0 base-4.14.1.0 mtl-2.2.2
haddock-interfaces:
    /usr/share/doc/haskell-stmonadtrans/html/STMonadTrans.haddock

haddock-html:         /usr/share/doc/haskell-stmonadtrans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
